#!/usr/bin/python
# -*- coding: utf-8 -*-

# BotMU.py
#
# This file is part of BotMU
#
# Author: Raphaël Perraudeau <r.perraudeau@gmail.com>
# Copyright: 2011 Raphaël Perraudeau <r.perraudeau@gmail.com>
# Licence: GNU/GPL
#
# Home page: <http://botmu.sourceforge.net/>

"""python BotMU.py"""

# Inclusions des modules générique
# Native
import sys
# Pyqt4
from PyQt4.QtCore import *
from PyQt4.QtGui import *
# Perso
from commonFunctions import *
from mainWidget import *
from cli import *

#############################################################################
class BotMUX(QMainWindow):

#========================================================================
	def __init__(self, app):
		try:
			QMainWindow.__init__(self)
			self.version = '1.0.0'
			self.fen = mainWidget(self)
			
			
			logErrorInitSession()
			self.setWindowIcon(QIcon(os.path.join(self.fen.execDir, "BotMU16.ico")))
			
			self.setCentralWidget(self.fen)

			traySignal = "activated(QSystemTrayIcon::ActivationReason)"
			self.connect(self.fen.trayIcon, SIGNAL(traySignal), self.__icon_activated)


			addlink = QAction(QIcon(os.path.join(self.fen.execDir, 'icons/addLink.png')), 'Ajouter un lien', self)
			addlink.setShortcut('Ctrl+A')
			addlink.setStatusTip('Ajouter un lien')

			addlist = QAction(QIcon(os.path.join(self.fen.execDir, 'icons/addList.png')), 'Ajouter une liste', self)
			addlist.setShortcut('Ctrl+O')
			addlist.setStatusTip('Ajouter une liste BotMU')

			savelist = QAction(QIcon(os.path.join(self.fen.execDir, 'icons/saveList.png')), 'Enregistrer', self)
			savelist.setShortcut('Ctrl+S')
			savelist.setStatusTip('Enregistrer la liste')
			
			startDl = QAction(QIcon(os.path.join(self.fen.execDir, 'icons/start.png')), u'Démarrer', self)
			startDl.setStatusTip(u'Démarrer le téléchargement')
			
			pauseDl = QAction(QIcon(os.path.join(self.fen.execDir, 'icons/pause.png')), u'Pause', self)
			pauseDl.setStatusTip(u'Mettre le téléchargement en pause')

			stopDl = QAction(QIcon(os.path.join(self.fen.execDir, 'icons/stop.png')), 'Stopper', self)
			stopDl.setStatusTip(u'Stopper le téléchargement')

			deleteList = QAction(QIcon(os.path.join(self.fen.execDir, 'icons/deleteList.png')), 'Vider la liste', self)
			deleteList.setStatusTip('Vider la liste')

			exit = QAction(QIcon(os.path.join(self.fen.execDir, 'icons/exit.png')), 'Quitter', self)
			exit.setStatusTip('Quitter l\'application')


			prefs = QAction(u'Préférences', self)
			prefs.setStatusTip(u'Préférences')

			about = QAction(QIcon(''), 'A Propos', self)
			
			#CLIPBOARD
			self.fen.clipboard = app.clipboard() 
			self.fen.clipboardValue = ""
			self.fen.clipboardLastValue = ""
			self.fen.clipboard.setText(self.fen.clipboardValue, QClipboard.Clipboard)
			self.connect(self.fen.clipboard, SIGNAL("dataChanged()"), self.fen.clipboardChanged)
			
			
			self.connect(exit, SIGNAL('triggered()'), SLOT('close()'))
			self.connect(addlink, SIGNAL('triggered()'), self.fen.addLink_m)
			self.connect(addlist, SIGNAL('triggered()'), self.fen.addList_m)
			self.connect(savelist, SIGNAL('triggered()'), self.fen.saveList_m)
			self.connect(deleteList, SIGNAL('triggered()'), self.fen.removeAllLink_m)
			self.connect(startDl, SIGNAL('triggered()'), self.fen.depart_m)
			self.connect(pauseDl, SIGNAL('triggered()'), self.fen.pause_m)
			self.connect(stopDl, SIGNAL('triggered()'), self.fen.stop_m)
			self.connect(prefs, SIGNAL('triggered()'), self.fen.showOptions_m)
			self.connect(about, SIGNAL('triggered()'), self.fen.showAbout_m)

			self.statusBar()

			menubar = self.menuBar()
			file = menubar.addMenu('&Fichier')
			file.addAction(addlink)
			file.addAction(addlist)
			file.addAction(savelist)
			file.addSeparator()
			file.addAction(exit)	
			
			edition = menubar.addMenu('&Edition')
			edition.addAction(prefs)
			
			help = menubar.addMenu('&?')
			help.addAction(about)

			toolbar = self.addToolBar('Bar')
			toolbar.setIconSize(QSize(32,32))
			toolbar.addAction(addlink)
			toolbar.addAction(addlist)
			toolbar.addAction(savelist)
			toolbar.addSeparator()
			toolbar.addAction(startDl)
			toolbar.addAction(pauseDl)
			toolbar.addAction(stopDl)
			toolbar.addSeparator()
			toolbar.addAction(deleteList)
			toolbar.addSeparator()
			toolbar.addAction(exit)
		except:
			logError("BotMU - init", sys.exc_info()[0], sys.exc_info()[1])



	# Event de fermeture
	#========================================================================
	def closeEvent(self, event):
		"""lancé à la fermeture de la fenêtre quelqu'en soit la méthode"""
		
		nbUncompleteFile = 0
		for downloadingFile in self.fen.fileList:
			if(isInt(downloadingFile[3]) and downloadingFile[3]!=100):
				nbUncompleteFile+=1
		
		
		#condition de message de fermeture
		if(nbUncompleteFile>0):
			msgBox = QMessageBox(self)
			msgBox.setWindowTitle("Quitter ?")
			msgBox.setIcon(QMessageBox.Warning)
			msgBox.setText(u"Voulez vous vraiment quitter ?\nSi un téléchargement est en cours, celui-ci sera arrêté.\nNéanmoins celui-ci pourra être repris la prochaine fois.")
			msgBox.addButton("Quitter", QMessageBox.YesRole)
			msgBox.addButton("Annuler", QMessageBox.NoRole)
			reply = msgBox.exec_()
			#Quitter
			if(reply==0):
				self.fen.saveSession()
				self.fen.trayIcon.hide()
				self.fen.stop_m()
				self.fen.clipboard.deleteLater()
				event.accept()
				sys.exit()
			#Annuler
			else:
				event.ignore()
		else:
			saveFile = os.path.join(self.fen.configDir, "lastsession.bsav")
			if os.path.exists(saveFile) and os.path.isfile(saveFile):
				try:
					sf = open(saveFile, "w+")
					sf.close()
				except:
					pass
			self.fen.trayIcon.hide()
			self.fen.stop_m()
			self.fen.clipboard.deleteLater()
			event.accept()
			sys.exit()

	def __icon_activated(self, reason):
		if reason == QSystemTrayIcon.DoubleClick:
			if self.isHidden():
				self.show()
			else:
				self.hide()
			

#############################################################################
if __name__ == "__main__":
	if("-l" in sys.argv or "-ll" in sys.argv):
		Cli()
	else:
		app = QApplication(sys.argv)
		app.setStyle(QStyleFactory.create("Plastique"))
		bot = BotMUX(app)
		bot.setWindowTitle("Bot MegaUpload %s" % bot.version)
		bot.show()
		sys.exit(app.exec_())
